@@ -26,6 +26,7 @@ from .bio_utils import printAlignment
 from .bio_utils import read_fastseq
 from .bio_utils import kmer_create
 
+from .deep_utils import mk_class_get
 from .deep_utils import get_params_size
 from .deep_utils import print_summary
 
@@ -69,6 +70,7 @@ from .metric_utils import pairwise_euclidean_distances
 from .model_select_utils import cross_validation
 
 from .monitor_utils import ConvergenceMonitor
+from .monitor_utils import ProgressMonitor
 from .monitor_utils import ThresholdMonitor
 
 from .np_utils import CategoricalEncoder
